package
Version:
v0.0.0-...-808094b
Opens a new window with list of versions in this module.
Published: Apr 28, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type App struct {
Neo4j Neo4j `yaml:"neo4j"`
Rest Rest `yaml:"rest"`
Graphql Graphql `yaml:"graphql"`
}
type Graphql struct {
Port int `yaml:"port"`
Host string `yaml:"host"`
Protocol string `yaml:"protocol"`
}
type Neo4j struct {
Uri string `yaml:"uri"`
Username string `yaml:"username"`
Password string `yaml:"password"`
}
type Rest struct {
Port int `yaml:"port"`
Host string `yaml:"host"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.