package
Version:
v0.0.0-...-808094b
Opens a new window with list of versions in this module.
Published: Apr 28, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type CreateGenreInput struct {
Name string `json:"name"`
}
type CreateSongInput struct {
Title string `json:"title"`
Artist string `json:"artist"`
GenreID uuid.UUID `json:"genreId"`
}
type CreateUserInput struct {
Email string `json:"email"`
UserName string `json:"userName"`
FavoriteGenres []string `json:"favoriteGenres"`
}
type GenreListDto struct {
ID uuid.UUID `json:"id"`
Name string `json:"name"`
}
type SongListDto struct {
ID uuid.UUID `json:"id"`
Title string `json:"title"`
Artist string `json:"artist"`
}
type UserListDto struct {
ID uuid.UUID `json:"id"`
UserName string `json:"userName"`
Email string `json:"email"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.